/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.application;

import java.util.List;

import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;

import kieker.analysis.model.analysisMetaModel.MIDependency;
import kieker.webgui.common.FileManager;

import org.primefaces.model.UploadedFile;

@ManagedBean
@ApplicationScoped
public class AvailableDependenciesBean {

	private final List<MIDependency> dependencies;

	/**
	 * Creates a new instance of this class.
	 */
	public AvailableDependenciesBean() {
		this.dependencies = FileManager.getInstance().loadAllDependencies();
	}

	/**
	 * Delivers the currently available dependencies as a list.
	 * 
	 * @return All available dependencies.
	 */
	public List<MIDependency> getDependencies() {
		return this.dependencies;
	}

	/**
	 * Tries to upload a given file as a new dependency. If the dependency does already exist, it will be overwritten.
	 * 
	 * @param file
	 *            The file to be uploaded.
	 */
	public void uploadDependency(final UploadedFile file) {
		final MIDependency dependency = FileManager.getInstance().uploadDependency(file);
		if (dependency != null) {
			/*
			 * Is is possible that we already have a dependency with the same name and have to remove it first.
			 */
			for (final MIDependency dep : this.dependencies) {
				if (dep.getFilePath().equals(dependency.getFilePath())) {
					this.dependencies.remove(dep);
					break;
				}
			}
			this.dependencies.add(dependency);
		}
	}

	/**
	 * Tries to delete a given dependency.
	 * 
	 * @param dependency
	 *            The dependency to be removed.
	 */
	public void deleteDependency(final MIDependency dependency) {
		final boolean result = FileManager.getInstance().deleteDependency(dependency);
		if (result) {
			this.dependencies.remove(dependency);
		}
	}
}
