/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/
package kieker.webgui.beans.session;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

import kieker.analysis.model.analysisMetaModel.MIProject;

import org.primefaces.event.NodeSelectEvent;
import org.primefaces.model.DefaultTreeNode;
import org.primefaces.model.TreeNode;

/**
 * This bean can be used to store the currently selected project and the current
 * main project for the user within a session.
 * 
 * @author Nils Christian Ehmke
 */
@ManagedBean
@SessionScoped
public class SelectedProjectBean {

	private TreeNode selectedNode;
	private MIProject selectedProject;
	private MIProject mainProject;

	/**
	 * Creates a new instance of this class.
	 */
	public SelectedProjectBean() {}

	/**
	 * Delivers the main project of the current user. It can be null.
	 * 
	 * @return The user's main project.
	 */
	public final MIProject getMainProject() {
		return this.mainProject;
	}

	/**
	 * Sets the main project of the current user.
	 * 
	 * @param mainProject
	 *            The new main project of the current user.
	 */
	public final void setMainProject(final MIProject mainProject) {
		this.mainProject = mainProject;
	}

	/**
	 * Delivers the project currently selected by the user. It can be null.
	 * 
	 * @return The user's currently selected project.
	 */
	public final MIProject getSelectedProject() {
		return this.selectedProject;
	}

	public final void setSelectedProject(final MIProject selectedProject) {
		this.selectedProject = selectedProject;
	}

	public final TreeNode getSelectedNode() {
		return this.selectedNode;
	}

	public final void onNodeSelect(final NodeSelectEvent event) {
		this.setSelectedNode(event.getTreeNode());
	}

	public final void setSelectedNode(final TreeNode selectedNode) {
		this.selectedNode = selectedNode;
		if (selectedNode != null && selectedNode.getData() instanceof MIProject) {
			this.setSelectedProject((MIProject) selectedNode.getData());
		} else {
			this.setSelectedProject(null);
		}
	}

	/**
	 * Delivers the "font weight" (whether the font is bold or normal) for a
	 * given project. This can be especially be used to mark a selected main
	 * project.
	 * 
	 * @param project
	 *            The project to be checked.
	 * @return "bold" if the given project is the current main project, "normal" otherwise.
	 */
	public final String getFontWeight(final MIProject project) {
		if (project == this.mainProject) {
			return "bold";
		} else {
			return "normal";
		}
	}

	/**
	 * Delivers the available plugins.
	 * 
	 * @return A tree with the available plugins.
	 */
	public final TreeNode getAvailablePluginsRoot() {
		final TreeNode root = new DefaultTreeNode("Root", null);

		final TreeNode readerNode = new DefaultTreeNode("default", "Reader", root);
		final TreeNode analysisPluginsNode = new DefaultTreeNode("default", "AnalysisPlugins", root);

		return root;
	}
}
