/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/
package kieker.webgui.converter;

import java.io.File;
import java.net.MalformedURLException;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.FacesConverter;

import kieker.analysis.model.analysisMetaModel.MIDependency;
import kieker.webgui.common.PluginFinder;

/**
 * This converter can be used to convert an instance of <i>MIDependency</i> to
 * the size (in MiBByte) of the dependency, but of course <b>not</b> vice versa.
 * 
 * @author Nils Christian Ehmke
 */
@FacesConverter(value = MIDependencyToCountPluginsConverter.NAME)
public class MIDependencyToCountPluginsConverter implements Converter {

	public static final String NAME = "kieker.webgui.converter.MIDependencyToCountPluginsConverter";

	/**
	 * Creates a new instance of this class.
	 */
	public MIDependencyToCountPluginsConverter() {}

	/**
	 * Delivers always null
	 */
	@Override
	public Object getAsObject(final FacesContext fc, final UIComponent uic, final String string) {
		return null;
	}

	@Override
	public String getAsString(final FacesContext fc, final UIComponent uic, final Object o) {
		if (o == null || !(o instanceof MIDependency)) {
			return "";
		} else {
			try {
				// TODO check why toURI().toURL() does not work instead of toURL()
				return Integer.toString(PluginFinder.getAllPluginsWithinJar(new File(((MIDependency) o).getFilePath()).toURL()).size());
			} catch (final MalformedURLException ex) {
				return "";
			} catch (final NullPointerException ex) {
				return "";
			}
		}
	}
}
