/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/
package kieker.webgui.converter;

import java.io.File;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.FacesConverter;

import kieker.analysis.model.analysisMetaModel.MIDependency;

/**
 * This converter can be used to convert an instance of <i>MIDependency</i> to a
 * human readable string, but <b>not</b> vice versa.
 * 
 * @author Nils Christian Ehmke
 */
@FacesConverter(value = MIDependencyToStringConverter.NAME)
public class MIDependencyToStringConverter implements Converter {

	/**
	 * This is the name of the converter.
	 */
	public static final String NAME = "kieker.webgui.converter.MIDependencyToStringConverter";

	/**
	 * Creates a new instance of this class.
	 */
	public MIDependencyToStringConverter() {}

	/**
	 * This method delivers always null and should not be used.
	 * 
	 * @param fc
	 *            The FacesContext for the request being processed.
	 * @param uic
	 *            The component with which this model object value is
	 *            associated.
	 * @param string
	 *            The string to be converted.
	 * @return null
	 */
	@Override
	public Object getAsObject(final FacesContext fc, final UIComponent uic, final String string) {
		return null;
	}

	/**
	 * This method converts the given object (on condition that it is an
	 * instance of the class <code>MIDependency</code>) to a human readable string.
	 * 
	 * @param fc
	 *            The FacesContext for the request being processed.
	 * @param uic
	 *            The component with which this model object value is
	 *            associated.
	 * @param o
	 *            The object to be converted.
	 * @return A human readable represantation of the given object or null, of
	 *         the object is from the wrong class.
	 */
	@Override
	public String getAsString(final FacesContext fc, final UIComponent uic, final Object o) {
		/*
		 * Make sure that the given object is well-defined.
		 */
		if (o == null || !(o instanceof MIDependency)) {
			return "";
		} else {
			return new File(((MIDependency) o).getFilePath()).getName();
		}
	}
}
